/**
 * 
 */
package com.samridhsai.ebulawa.utils;
import org.slf4j.Logger;

import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
/**
 * @author kondojis
 *
 */


public class SessionActiveInterceptor extends HandlerInterceptorAdapter {
    private Logger logger = org.slf4j.LoggerFactory.getLogger(SessionActiveInterceptor.class);

    /**
     * @param request           Http request object
     * @param response          Http response object
     * @param handler           chosen handler to execute, for type and/or instance evaluation
     * @return                  true if the execution chain should proceed with the next interceptor
     *                          or the handler itself. Else, DispatcherServlet assumes that this interceptor
     *                          has already dealt with the response itself.
     * @throws Exception
     */
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler)
            throws Exception {
    	
        HttpSession session = request.getSession(false);
        
        logger.debug("Request path "+ request.getServletPath());
        
        String servletPath = request.getServletPath();
        
        if (servletPath.equalsIgnoreCase("/") ||
                servletPath.equalsIgnoreCase("/pages/*")) {
        	//Ignore session timeouts on public pages.
            return true;
        }
        else {
            if (session == null || !request.isRequestedSessionIdValid()) {
               logger.debug(
                        "SessionActiveInterceptor :: Attempt to take action when session is timed out or objects in session are null");
                response.sendRedirect(exitToSessionTimeOutPage);
                return false;
            }
            else
                return true;
        }
    }

    /**
     *
     * @return    Redirection path to be used on session expiry
     */
    public String getExitToSessionTimeOutPage() {
        return exitToSessionTimeOutPage;
    }

    /**
     *
     * @param exitPath    Redirection url to be used on session expiry
     */
    public void setExitToSessionTimeOutPage(String exitPath) {
        this.exitToSessionTimeOutPage = exitPath;
    }
    private String exitToSessionTimeOutPage;

}

